@@ -68,8 +68,8 @@ class JobManager(object):
         1. Creates model_class instance, possibly by using artefacts from previously finished jobs
         2. Calls model_class.process_event() method
         :param model_class: AIxBlockMLBase instance
-        :param event: event name (e.g. Label Studio webhook action name)
-        :param data: job data (e.g. Label Studio webhook payload)
+        :param event: event name (e.g. AIxBlockwebhook action name)
+        :param data: job data (e.g. AIxBlockwebhook payload)
         :param job_id: user-defined job identifier
         :return: json-serializable job result
         """
@@ -306,15 +306,15 @@ class AIxBlockMLBase(ABC):
         self.hostname = kwargs.get('hostname', '')
         self.access_token = kwargs.get('access_token', '')
 
-    @abstractmethod
-    def predict(self, tasks, **kwargs):
-        pass
-    @abstractmethod
-    def toolbar_predict(self, image, clickpoint, polygons, vertices,project, **kwargs):
-        pass
-    @abstractmethod
-    def toolbar_predict_sam(self, image, clickpoint, polygons, vertices,project,voice,prompt,image_pref,draw_polygons, **kwargs):
-        pass
+    # @abstractmethod
+    # def predict(self, tasks, **kwargs):
+    #     pass
+    # @abstractmethod
+    # def toolbar_predict(self, image, clickpoint, polygons, vertices,project, **kwargs):
+    #     pass
+    # @abstractmethod
+    # def toolbar_predict_sam(self, image, clickpoint, polygons, vertices,project,voice,prompt,image_pref,draw_polygons, **kwargs):
+    #     pass
     @abstractmethod
     def action(self, project,command, collection, **kwargs):
         pass
@@ -322,8 +322,11 @@ class AIxBlockMLBase(ABC):
     def model(self,project, **kwargs):
         pass
     @abstractmethod
-    def preview(self,project, **kwargs):
+    def model_trial(self,project, **kwargs):
         pass
+    # @abstractmethod
+    # def preview(self,project, **kwargs):
+    #     pass
     @abstractmethod
     def download(self,project, **kwargs):
         pass
@@ -591,43 +594,43 @@ class AIxBlockMLManager(object):
                 'model_version': m.model_version
             }
 
-    @classmethod
-    def predict(
-        cls, tasks, project=None, label_config=None, force_reload=False, try_fetch=True, **kwargs
-    ):
-        if not os.getenv('AIXBLOCK_ML_BACKEND_V2', default=AIXBLOCK_ML_BACKEND_V2_DEFAULT):
-            if try_fetch:
-                m = cls.fetch(project, label_config, force_reload)
-            else:
-                m = cls.get(project)
-                if not m:
-                    raise FileNotFoundError('No model loaded. Specify "try_fetch=True" option.')
-            predictions = m.model.predict(tasks, **kwargs)
-            return predictions, m
+    # @classmethod
+    # def predict(
+    #     cls, tasks, project=None, label_config=None, force_reload=False, try_fetch=True, **kwargs
+    # ):
+    #     if not os.getenv('AIXBLOCK_ML_BACKEND_V2', default=AIXBLOCK_ML_BACKEND_V2_DEFAULT):
+    #         if try_fetch:
+    #             m = cls.fetch(project, label_config, force_reload)
+    #         else:
+    #             m = cls.get(project)
+    #             if not m:
+    #                 raise FileNotFoundError('No model loaded. Specify "try_fetch=True" option.')
+    #         predictions = m.model.predict(tasks, **kwargs)
+    #         return predictions, m
 
-        if not cls._current_model:
-            raise ValueError(f'Model is not loaded for {cls.__class__.__name__}: run setup() before using predict()')
+    #     if not cls._current_model:
+    #         raise ValueError(f'Model is not loaded for {cls.__class__.__name__}: run setup() before using predict()')
 
-        predictions = cls._current_model.model.predict(tasks, **kwargs)
-        return predictions, cls._current_model
-    @classmethod
-    def toolbar_predict(
-        cls, image, clickpoint, polygons, vertices, project=None, label_config=None, force_reload=True, try_fetch=False, **kwargs
-    ):
-        if not os.getenv('AIXBLOCK_ML_BACKEND_V2', default=AIXBLOCK_ML_BACKEND_V2_DEFAULT):
-            if try_fetch:
-                m = cls.fetch(project, label_config, force_reload)
-            else:
-                m = cls.get(project)
-                if not m:
-                    raise FileNotFoundError('No model loaded. Specify "try_fetch=True" option.')
-            predictions = m.model.toolbar_predict(image, clickpoint, polygons, vertices,project, **kwargs)
-            return predictions, m
+    #     predictions = cls._current_model.model.predict(tasks, **kwargs)
+    #     return predictions, cls._current_model
+    # @classmethod
+    # def toolbar_predict(
+    #     cls, image, clickpoint, polygons, vertices, project=None, label_config=None, force_reload=True, try_fetch=False, **kwargs
+    # ):
+    #     if not os.getenv('AIXBLOCK_ML_BACKEND_V2', default=AIXBLOCK_ML_BACKEND_V2_DEFAULT):
+    #         if try_fetch:
+    #             m = cls.fetch(project, label_config, force_reload)
+    #         else:
+    #             m = cls.get(project)
+    #             if not m:
+    #                 raise FileNotFoundError('No model loaded. Specify "try_fetch=True" option.')
+    #         predictions = m.model.toolbar_predict(image, clickpoint, polygons, vertices,project, **kwargs)
+    #         return predictions, m
 
-        if not cls._current_model:
-            raise ValueError(f'Model is not loaded for {cls.__class__.__name__}: run setup() before using toolbar_predict()')
-        predictions = m.model.toolbar_predict( image, clickpoint, polygons, vertices,project, **kwargs)
-        return predictions, m
+    #     if not cls._current_model:
+    #         raise ValueError(f'Model is not loaded for {cls.__class__.__name__}: run setup() before using toolbar_predict()')
+    #     predictions = m.model.toolbar_predict( image, clickpoint, polygons, vertices,project, **kwargs)
+    #     return predictions, m
     @classmethod
     def action(
         cls,  project=None, command=None, collection=None, label_config=None, force_reload=True, try_fetch=False, **kwargs
@@ -646,24 +649,24 @@ class AIxBlockMLManager(object):
             raise ValueError(f'Model is not loaded for {cls.__class__.__name__}: run setup() before using toolbar_predict()')
         predictions = m.model.action( project,  command,collection,**kwargs)
         return predictions, m
-    @classmethod
-    def toolbar_predict_sam(
-        cls, image, clickpoint, polygons, vertices, project=None, voice=None,prompt=None,image_pref=None,draw_polygons=None,label_config=None, force_reload=True, try_fetch=False, **kwargs
-    ):
-        if not os.getenv('AIXBLOCK_ML_BACKEND_V2', default=AIXBLOCK_ML_BACKEND_V2_DEFAULT):
-            if try_fetch:
-                m = cls.fetch(project, label_config, force_reload)
-            else:
-                m = cls.get(project)
-                if not m:
-                    raise FileNotFoundError('No model loaded. Specify "try_fetch=True" option.')
-            predictions = m.model.toolbar_predict_sam(image, clickpoint, polygons, vertices,project, voice,prompt,image_pref,draw_polygons,**kwargs)
-            return predictions, m
+    # @classmethod
+    # def toolbar_predict_sam(
+    #     cls, image, clickpoint, polygons, vertices, project=None, voice=None,prompt=None,image_pref=None,draw_polygons=None,label_config=None, force_reload=True, try_fetch=False, **kwargs
+    # ):
+    #     if not os.getenv('AIXBLOCK_ML_BACKEND_V2', default=AIXBLOCK_ML_BACKEND_V2_DEFAULT):
+    #         if try_fetch:
+    #             m = cls.fetch(project, label_config, force_reload)
+    #         else:
+    #             m = cls.get(project)
+    #             if not m:
+    #                 raise FileNotFoundError('No model loaded. Specify "try_fetch=True" option.')
+    #         predictions = m.model.toolbar_predict_sam(image, clickpoint, polygons, vertices,project, voice,prompt,image_pref,draw_polygons,**kwargs)
+    #         return predictions, m
 
-        if not cls._current_model:
-            raise ValueError(f'Model is not loaded for {cls.__class__.__name__}: run setup() before using toolbar_predict()')
-        predictions = m.model.toolbar_predict_sam( image, clickpoint, polygons, vertices,project, voice,prompt,image_pref,draw_polygons,**kwargs)
-        return predictions, m
+    #     if not cls._current_model:
+    #         raise ValueError(f'Model is not loaded for {cls.__class__.__name__}: run setup() before using toolbar_predict()')
+    #     predictions = m.model.toolbar_predict_sam( image, clickpoint, polygons, vertices,project, voice,prompt,image_pref,draw_polygons,**kwargs)
+    #     return predictions, m
     @classmethod
     def model(cls,project=None,label_config=None, force_reload=True, try_fetch=False, **kwargs):
         if not os.getenv('AIXBLOCK_ML_BACKEND_V2', default=AIXBLOCK_ML_BACKEND_V2_DEFAULT):
@@ -681,12 +684,28 @@ class AIxBlockMLManager(object):
         predictions = m.model.model(project, **kwargs)
         return predictions, m
     @classmethod
-    def preview(cls, project):
-        if not cls.has_active_model(project):
-            return {}
-        m = cls.get(project)
-        repos = m.model.preview(project)
-        return repos
+    def model_trial(cls,project=None,label_config=None, force_reload=True, try_fetch=False, **kwargs):
+        if not os.getenv('AIXBLOCK_ML_BACKEND_V2', default=AIXBLOCK_ML_BACKEND_V2_DEFAULT):
+            if try_fetch:
+                m = cls.fetch(project, label_config, force_reload)
+            else:
+                m = cls.get(project)
+                if not m:
+                    raise FileNotFoundError('No model loaded. Specify "try_fetch=True" option.')
+            predictions = m.model.model(project, **kwargs)
+            return predictions, m
+
+        if not cls._current_model:
+            raise ValueError(f'Model is not loaded for {cls.__class__.__name__}: run setup() before using model()')
+        predictions = m.model.model(project, **kwargs)
+        return predictions, m
+    # @classmethod
+    # def preview(cls, project):
+    #     if not cls.has_active_model(project):
+    #         return {}
+    #     m = cls.get(project)
+    #     repos = m.model.preview(project)
+    #     return repos
     @classmethod
     def download(cls, project):
         if not cls.has_active_model(project):
